==> wix_media_platform-1.70.0.tar.gz: wix_media_platform-1.70.0/README.md <==
# Wix Media Platform

[![Build Status][travis-image]][travis-url] 

[Wix Media Platform][wixmp-url] is an end-to-end solution for all modern web media management, handling images, video and audio in the most efficient way on the market. From upload, storage, metadata management and all the way to delivery, Wix Media Platform takes care of all possible media work flows.

# Python SDK
 
## Installation

```bash
pip install wix-media-platform
```

## Reporting Issues

Please use [the issue tracker](https://github.com/wix/media-platform-python-sdk/issues) to report issues related to this library, or to the Wix Media Platform API in general.

## Develop
If you want to help make Media Platform Python SDK better - you are welcome and **you are awesome**!

- Create an issue or make a Pull Request
- Use [conventional commits](https://www.conventionalcommits.org/en/v1.0.0-beta.2/) for commits names.

## License

We use a custom license, see [LICENSE.md](LICENSE.md).

## About Wix

[Wix.com][wix-url] is a leading cloud-based web development platform with more than 100 million registered users worldwide. 
Our powerful technology makes it simple for everyone to create a beautiful website and grow their business online.

## About Google Cloud Platform

[Google Cloud Platform][google-url] enables developers to build, test and deploy applications on Google’s reliable infrastructure.
It offers computing, storage and application services for web, mobile and backend solutions.


[wix-url]: https://www.wix.com/
[google-url]: https://cloud.google.com/
[wixmp-url]: https://console.wixmp.com/

[travis-image]: https://travis-ci.org/wix/media-platform-python-sdk.svg?branch=master
[travis-url]: https://travis-ci.org/wix/media-platform-python-sdk

..

## Releasing manually

set PACKAGE_VERSION in setup.py

```shell
python setup.py sdist
twine upload dist/*
```

==> wix_media_platform-1.73.0.tar.gz: wix_media_platform-1.73.0/README.md <==
# Wix Media Platform

[![Build Status][travis-image]][travis-url] 

[Wix Media Platform][wixmp-url] is an end-to-end solution for all modern web media management, handling images, video and audio in the most efficient way on the market. From upload, storage, metadata management and all the way to delivery, Wix Media Platform takes care of all possible media work flows.

# Python SDK
 
## Installation

```bash
pip install wix-media-platform
```

## Reporting Issues

Please use [the issue tracker](https://github.com/wix/media-platform-python-sdk/issues) to report issues related to this library, or to the Wix Media Platform API in general.

## Develop
If you want to help make Media Platform Python SDK better - you are welcome and **you are awesome**!

- Create an issue or make a Pull Request
- Use [conventional commits](https://www.conventionalcommits.org/en/v1.0.0-beta.2/) for commits names.

## License

We use a custom license, see [LICENSE.md](LICENSE.md).

## About Wix

[Wix.com][wix-url] is a leading cloud-based web development platform with more than 100 million registered users worldwide. 
Our powerful technology makes it simple for everyone to create a beautiful website and grow their business online.

## About Google Cloud Platform

[Google Cloud Platform][google-url] enables developers to build, test and deploy applications on Google’s reliable infrastructure.
It offers computing, storage and application services for web, mobile and backend solutions.


[wix-url]: https://www.wix.com/
[google-url]: https://cloud.google.com/
[wixmp-url]: https://console.wixmp.com/

[travis-image]: https://travis-ci.org/wix/media-platform-python-sdk.svg?branch=master
[travis-url]: https://travis-ci.org/wix/media-platform-python-sdk

..

## Releasing manually

set PACKAGE_VERSION in setup.py

```shell
python setup.py sdist
twine upload dist/*
```


## Running Demo locally
update globals.py with project wixmp-38be4d0b88020d170fae2a8d, application 3966649e6f1a4a9db374a88dc63a6132 and its secret.

```
virtualenv -p python3 run
source run/bin/activate 
pip install .

```
